From 98ca73afe51e1e921915c37f242c88d4d445841c Mon Sep 17 00:00:00 2001
From: Frederic Cambus <fred@statdns.com>
Date: Sat, 11 Sep 2021 23:30:22 +0200
Subject: [PATCH] Add support to readelf for reading OpenBSD ELF core notes.

	* readelf.c (get_openbsd_elfcore_note_type): New function.
	(process_note): Add support for OpenBSD core notes.
---
 binutils/readelf.c | 24 ++++++++++++++++++++++++
 1 file changed, 24 insertions(+)

diff --git a/binutils/readelf.c b/binutils/readelf.c
index 4a6fcff3cc1..3b6f1a3ab1d 100644
--- a/binutils/readelf.c
+++ b/binutils/readelf.c
@@ -19989,6 +19989,26 @@ get_netbsd_elfcore_note_type (Filedata * filedata, unsigned e_type)
   return buff;
 }
 
+static const char *
+get_openbsd_elfcore_note_type (Filedata * filedata, unsigned e_type)
+{
+  switch (e_type)
+    {
+    case NT_OPENBSD_PROCINFO:
+      return _("OpenBSD procinfo structure");
+    case NT_OPENBSD_AUXV:
+      return _("OpenBSD ELF auxiliary vector data");
+    case NT_OPENBSD_REGS:
+      return _("OpenBSD regular registers");
+    case NT_OPENBSD_FPREGS:
+      return _("OpenBSD floating point registers");
+    case NT_OPENBSD_WCOOKIE:
+      return _("OpenBSD window cookie");
+    }
+
+  return get_note_type (filedata, e_type);
+}
+
 static const char *
 get_stapsdt_note_type (unsigned e_type)
 {
@@ -20770,6 +20790,10 @@ process_note (Elf_Internal_Note *  pnote,
     /* NetBSD-specific core file notes.  */
     return process_netbsd_elf_note (pnote);
 
+  else if (startswith (pnote->namedata, "OpenBSD"))
+    /* OpenBSD-specific core file notes.  */
+    nt = get_openbsd_elfcore_note_type (filedata, pnote->type);
+
   else if (startswith (pnote->namedata, "SPU/"))
     {
       /* SPU-specific core file notes.  */
-- 
2.31.1

